@@ -267,7 +267,8 @@ void test_all_help_cmd(void){
     mask = CMDFLAG_WEBPAGE;
   }
   if( find_option("everything","e",0) ){
-    mask = CMDFLAG_1ST_TIER | CMDFLAG_2ND_TIER | CMDFLAG_WEBPAGE;
+    mask = CMDFLAG_1ST_TIER | CMDFLAG_2ND_TIER | CMDFLAG_WEBPAGE |
+              CMDFLAG_SETTING | CMDFLAG_TEST;
   }
   if( find_option("settings","s",0) ){
     mask = CMDFLAG_SETTING;
@@ -351,130 +352,68 @@ void help_page(void){
       }
     }
   }else{
-    int i, j, n;
+    int i;
 
     style_header("Help");
 
     @ <a name='commands'></a>
     @ <h1>Available commands:</h1>
-    @ <table border="0"><tr>
-    for(i=j=0; i<MX_COMMAND; i++){
-      const char *z = aCommand[i].zName;
-      if( '/'==*z || strncmp(z,"test",4)==0 ) continue;
-      j++;
-    }
-    n = (j+5)/6;
-    for(i=j=0; i<MX_COMMAND; i++){
+    @ <div class="columns" style="column-width: 12ex;">
+    @ <ul>
+    for(i=0; i<MX_COMMAND; i++){
       const char *z = aCommand[i].zName;
       const char *zBoldOn  = aCommand[i].eCmdFlags&CMDFLAG_1ST_TIER?"<b>" :"";
       const char *zBoldOff = aCommand[i].eCmdFlags&CMDFLAG_1ST_TIER?"</b>":"";
       if( '/'==*z || strncmp(z,"test",4)==0 ) continue;
-      if( j==0 ){
-        @ <td valign="top"><ul>
-      }
+      if( (aCommand[i].eCmdFlags & CMDFLAG_SETTING)!=0 ) continue;
       @ <li><a href="%R/help?cmd=%s(z)">%s(zBoldOn)%s(z)%s(zBoldOff)</a></li>
-      j++;
-      if( j>=n ){
-        @ </ul></td>
-        j = 0;
-      }
     }
-    if( j>0 ){
-      @ </ul></td>
-    }
-    @ </tr></table>
+    @ </ul></div>
 
     @ <a name='webpages'></a>
     @ <h1>Available web UI pages:</h1>
-    @ <table border="0"><tr>
-    for(i=j=0; i<MX_COMMAND; i++){
+    @ <div class="columns" style="column-width: 18ex;">
+    @ <ul>
+    for(i=0; i<MX_COMMAND; i++){
       const char *z = aCommand[i].zName;
       if( '/'!=*z ) continue;
-      j++;
-    }
-    n = (j+4)/5;
-    for(i=j=0; i<MX_COMMAND; i++){
-      const char *z = aCommand[i].zName;
-      if( '/'!=*z ) continue;
-      if( j==0 ){
-        @ <td valign="top"><ul>
-      }
       if( aCommand[i].zHelp[0] ){
         @ <li><a href="%R/help?cmd=%s(z)">%s(z+1)</a></li>
       }else{
         @ <li>%s(z+1)</li>
       }
-      j++;
-      if( j>=n ){
-        @ </ul></td>
-        j = 0;
-      }
     }
-    if( j>0 ){
-      @ </ul></td>
-    }
-    @ </tr></table>
+    @ </ul></div>
 
     @ <a name='unsupported'></a>
     @ <h1>Unsupported commands:</h1>
-    @ <table border="0"><tr>
-    for(i=j=0; i<MX_COMMAND; i++){
+    @ <div class="columns" style="column-width: 20ex;">
+    @ <ul>
+    for(i=0; i<MX_COMMAND; i++){
       const char *z = aCommand[i].zName;
       if( strncmp(z,"test",4)!=0 ) continue;
-      j++;
-    }
-    n = (j+3)/4;
-    for(i=j=0; i<MX_COMMAND; i++){
-      const char *z = aCommand[i].zName;
-      if( strncmp(z,"test",4)!=0 ) continue;
-      if( j==0 ){
-        @ <td valign="top"><ul>
-      }
       if( aCommand[i].zHelp[0] ){
         @ <li><a href="%R/help?cmd=%s(z)">%s(z)</a></li>
       }else{
         @ <li>%s(z)</li>
       }
-      j++;
-      if( j>=n ){
-        @ </ul></td>
-        j = 0;
-      }
     }
-    if( j>0 ){
-      @ </ul></td>
-    }
-    @ </tr></table>
+    @ </ul></div>
 
     @ <a name='settings'></a>
     @ <h1>Settings:</h1>
-    @ <table border="0"><tr>
-    for(i=j=0; i<MX_COMMAND; i++){
-      if( (aCommand[i].eCmdFlags & CMDFLAG_SETTING)==0 ) continue;
-      j++;
-    }
-    n = (j+4)/5;
-    for(i=j=0; i<MX_COMMAND; i++){
+    @ <div class="columns" style="column-width: 20ex;">
+    @ <ul>
+    for(i=0; i<MX_COMMAND; i++){
       const char *z = aCommand[i].zName;
       if( (aCommand[i].eCmdFlags & CMDFLAG_SETTING)==0 ) continue;
-      if( j==0 ){
-        @ <td valign="top"><ul>
-      }
       if( aCommand[i].zHelp[0] ){
         @ <li><a href="%R/help?cmd=%s(z)">%s(z)</a></li>
       }else{
         @ <li>%s(z)</li>
       }
-      j++;
-      if( j>=n ){
-        @ </ul></td>
-        j = 0;
-      }
     }
-    if( j>0 ){
-      @ </ul></td>
-    }
-    @ </tr></table>
+    @ </ul></div>
 
   }
   style_footer();
@@ -554,6 +493,33 @@ static void command_list(const char *zPrefix, int cmdMask){
   multi_column_list(aCmd, nCmd);
 }
 
+/*
+** Documentation on universal command-line options.
+*/
+/* @-comment: # */
+static const char zOptions[] =
+@ Command-line options common to all commands:
+@ 
+@   --args FILENAME         Read additional arguments and options from FILENAME
+@   --cgitrace              Active CGI tracing
+@   --comfmtflags VALUE     Set comment formatting flags to VALUE
+@   --comment-format VALUE  Alias for --comfmtflags
+@   --errorlog FILENAME     Log errors to FILENAME 
+@   --help                  Show help on the command rather than running it
+@   --httptrace             Trace outbound HTTP requests
+@   --localtime             Display times using the local timezone
+@   --no-th-hook            Do not run TH1 hooks
+@   --quiet                 Reduce the amount of output
+@   --sqlstats              Show SQL usage statistics when done
+@   --sqltrace              Trace all SQL commands
+@   --sshtrace              Trace SSH activity
+@   --ssl-identity NAME     Set the SSL identity to NAME
+@   --systemtrace           Trace calls to system()
+@   --user|-U USER          Make the default user be USER
+@   --utc                   Display times using UTC
+@   --vfs NAME              Cause SQLite to use the NAME VFS
+;
+
 /*
 ** COMMAND: help
 **
@@ -566,7 +532,8 @@ static void command_list(const char *zPrefix, int cmdMask){
 **
 **    %fossil help                Show common commands
 **    %fossil help -a|--all       Show both common and auxiliary commands
-**    %fossil help -s|--settings  Show setting names
+**    %fossil help -o|--options   Show command-line options common to all cmds
+**    %fossil help -s|--setting   Show setting names
 **    %fossil help -t|--test      Show test commands only
 **    %fossil help -x|--aux       Show auxiliary commands only
 **    %fossil help -w|--www       Show list of webpages
@@ -582,12 +549,16 @@ void help_cmd(void){
     z = g.argv[0];
     fossil_print(
       "Usage: %s help TOPIC\n"
-      "Common commands:  (use \"%s help -a|--all\" for a complete list)\n",
+      "Common commands:  (use \"%s help help\" for more options)\n",
       z, z);
     command_list(0, CMDFLAG_1ST_TIER);
     version_cmd();
     return;
   }
+  if( find_option("options","o",0) ){
+    fossil_print("%s", zOptions);
+    return;
+  }
   if( find_option("all","a",0) ){
     command_list(0, CMDFLAG_1ST_TIER | CMDFLAG_2ND_TIER);
     return;
